@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-embed.h,v 1.41.4.1 2004/10/06 13:28:29 chpe Exp $
+ *  $Id: ephy-embed.h,v 1.41.4.2 2004/10/30 17:49:42 chpe Exp $
  */
 
 #ifndef EPHY_EMBED_H
@@ -131,6 +131,8 @@ struct _EphyEmbedIface
 					 float new_zoom);
 	void	 (* content_change)	(EphyEmbed *embed,
 					 const char *uri);
+	gboolean (* modal_alert)	(EphyEmbed *embed);
+	void	 (* modal_alert_closed)	(EphyEmbed *embed);
 
 	/* Methods  */
 	void		   (* load_url)			(EphyEmbed *embed,
