@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EventContext.cpp,v 1.39 2004/08/15 22:24:01 chpe Exp $
+ *  $Id: EventContext.cpp,v 1.39.4.3 2004/11/13 19:56:49 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -33,7 +33,9 @@
 
 #include <nsIInterfaceRequestor.h>
 #include <nsIServiceManager.h>
+#define MOZILLA_STRICT_API
 #include <nsEmbedString.h>
+#undef MOZILLA_STRICT_API
 #include <nsIDOMEventTarget.h>
 #include <nsIDOMHTMLInputElement.h>
 #include <nsIDOMHTMLObjectElement.h>
@@ -142,7 +144,6 @@ nsresult EventContext::GatherTextUnder (nsIDOMNode* aNode, nsAString& aResult)
 				}
 				else
 				{
-					nsCOMPtr<nsIDOMNode> nextSibling;
 					parentNode->GetNextSibling(getter_AddRefs(nextSibling));
 					node = nextSibling;
 					depth--;
@@ -371,7 +372,6 @@ nsresult EventContext::GetEventContext (nsIDOMEventTarget *EventTarget,
 			}
 		}
 
-		PRUint16 type;
 		rv = node->GetNodeType(&type);
 		if (NS_FAILED(rv)) return NS_ERROR_FAILURE;
 
@@ -579,7 +579,7 @@ nsresult EventContext::GetCSSBackground (nsIDOMNode *node, nsAString& url)
 nsresult EventContext::GetMouseEventInfo (nsIDOMMouseEvent *aMouseEvent, MozillaEmbedEvent *info)
 {
 	/* FIXME: casting 32-bit guint* to PRUint16* below will break on big-endian */
-	PRUint16 btn;
+	PRUint16 btn = (PRUint16) -1;
 	aMouseEvent->GetButton (&btn);
 
 	switch (btn)
